<?php

// Require
require_once __DIR__ . '/../DeepCopy/autoload.php';
require_once __DIR__ . '/../PharIo/Manifest/autoload.php';
require_once __DIR__ . '/../PharIo/Version/autoload.php';
require_once __DIR__ . '/../SebastianBergmann/CliParser/autoload.php';
require_once __DIR__ . '/../SebastianBergmann/CodeCoverage/autoload.php';
require_once __DIR__ . '/../SebastianBergmann/CodeUnit/autoload.php';
require_once __DIR__ . '/../SebastianBergmann/Comparator/autoload.php';
require_once __DIR__ . '/../SebastianBergmann/Diff/autoload.php';
require_once __DIR__ . '/../SebastianBergmann/Environment/autoload.php';
require_once __DIR__ . '/../SebastianBergmann/Exporter/autoload.php';
require_once __DIR__ . '/../SebastianBergmann/FileIterator/autoload.php';
require_once __DIR__ . '/../SebastianBergmann/GlobalState/autoload.php';
require_once __DIR__ . '/../SebastianBergmann/Invoker/autoload.php';
require_once __DIR__ . '/../SebastianBergmann/ObjectEnumerator/autoload.php';
require_once __DIR__ . '/../SebastianBergmann/Template/autoload.php';
require_once __DIR__ . '/../SebastianBergmann/Timer/autoload.php';
require_once __DIR__ . '/../SebastianBergmann/Type/autoload.php';
require_once __DIR__ . '/../SebastianBergmann/Version/autoload.php';
require_once __DIR__ . '/../staabm/SideEffectsDetector/autoload.php';

// Suggest

// @codingStandardsIgnoreFile
// @codeCoverageIgnoreStart
// this is an autogenerated file - do not edit
spl_autoload_register(
    function($class) {
        static $classes = null;
        if ($classes === null) {
            $classes = array(
                ___CLASSLIST___
            );
        }
        $cn = strtolower($class);
        if (isset($classes[$cn])) {
            require ___BASEDIR___$classes[$cn];
        }
    },
    ___EXCEPTION___,
    ___PREPEND___
);
// @codeCoverageIgnoreEnd

// Files
require_once __DIR__.'/Framework/Assert/Functions.php';
